==> jc-1.4.0.tar.gz: java/io/ObjectInputStream__24ValidatorAndPriority.h <==
// final class java.io.ObjectInputStream$ValidatorAndPriority

// class file dependencies
// @dep_class 1958e690a538b400 java_io_ObjectInputStream__24ValidatorAndPriority
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_ObjectInputStream__24ValidatorAndPriority_H_
#define _JC_java_io_ObjectInputStream__24ValidatorAndPriority_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputValidation$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_refs	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_refs;
typedef struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_nonrefs	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_nonrefs;
typedef struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$refs	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$refs;
typedef struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$nonrefs	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$nonrefs;
typedef struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$object	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$object;

typedef const struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vmethods	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vmethods;
typedef const struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtable	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtable;
typedef const struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtype	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtype;

// Constructors
extern void _jc_java_io_ObjectInputStream__24ValidatorAndPriority$method$_init$b5030e505178eead(_jc_env *, struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$object *, struct _jc_object *, jint);

// Virtual methods
extern jint _jc_java_io_ObjectInputStream__24ValidatorAndPriority$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_ObjectInputStream__24ValidatorAndPriority$method_info$compareTo$84fc6fc4a23c98a3;

// Virtual methods structure
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vmethods	java_io_ObjectInputStream__24ValidatorAndPriority;
};

// Vtype
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtype {
	_jc_type			type;
	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_refs {
	struct _jc_object	*validator;
};

// Reference instance fields (object)
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$refs {
    _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_refs	java_io_ObjectInputStream__24ValidatorAndPriority;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_nonrefs {
	jint	priority;
};

// Non-reference instance fields (object)
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_nonrefs	java_io_ObjectInputStream__24ValidatorAndPriority;
};

// Object instance structure
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$object {
	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtype	*vtype;
	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtype _jc_java_io_ObjectInputStream__24ValidatorAndPriority$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ObjectInputStream__24ValidatorAndPriority, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ObjectInputStream__24ValidatorAndPriority$class_object;

#endif	/* _JC_java_io_ObjectInputStream__24ValidatorAndPriority_H_ */

==> jc-1.4.5.tar.gz: java/io/ObjectInputStream__24ValidatorAndPriority.h <==
// final class java.io.ObjectInputStream$ValidatorAndPriority

// class file dependencies
// @dep_class 8a40bfd89573b304 java_io_ObjectInputStream__24ValidatorAndPriority
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_io_ObjectInputStream__24ValidatorAndPriority_H_
#define _JC_java_io_ObjectInputStream__24ValidatorAndPriority_H_

// Forward structure declarations
struct _jc_java_io_ObjectInputValidation$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_refs	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_refs;
typedef struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_nonrefs	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_nonrefs;
typedef struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$refs	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$refs;
typedef struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$nonrefs	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$nonrefs;
typedef struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$object	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$object;

typedef const struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vmethods	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vmethods;
typedef const struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtable	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtable;
typedef const struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtype	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtype;

// Constructors
extern void _jc_java_io_ObjectInputStream__24ValidatorAndPriority$method$_init$b5030e505178eead(_jc_env *, struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_io_ObjectInputStream__24ValidatorAndPriority$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_ObjectInputStream__24ValidatorAndPriority$method_info$compareTo$84fc6fc4a23c98a3;

// Virtual methods structure
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vmethods	java_io_ObjectInputStream__24ValidatorAndPriority;
};

// Vtype
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtype {
	_jc_type			type;
	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_refs {
	struct _jc_object	*validator;
};

// Reference instance fields (object)
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$refs {
    _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_refs	java_io_ObjectInputStream__24ValidatorAndPriority;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_nonrefs {
	jint	priority;
};

// Non-reference instance fields (object)
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_ObjectInputStream__24ValidatorAndPriority$sub_nonrefs	java_io_ObjectInputStream__24ValidatorAndPriority;
};

// Object instance structure
struct _jc_java_io_ObjectInputStream__24ValidatorAndPriority$object {
	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtype	*vtype;
	_jc_java_io_ObjectInputStream__24ValidatorAndPriority$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_ObjectInputStream__24ValidatorAndPriority$vtype _jc_java_io_ObjectInputStream__24ValidatorAndPriority$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ObjectInputStream__24ValidatorAndPriority, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ObjectInputStream__24ValidatorAndPriority$class_object;

#endif	/* _JC_java_io_ObjectInputStream__24ValidatorAndPriority_H_ */
